@@ -162,6 +162,10 @@ create_account_details_ui (GoaProvider    *provider,
   GoaProviderDialog *dialog = GOA_PROVIDER_DIALOG (data->dialog);
   GtkWidget *group;
 
+  goa_provider_dialog_add_page (dialog,
+                                NULL,
+                                _("Access restricted web and network resources for your organization"));
+
   group = goa_provider_dialog_add_group (dialog, NULL);
   data->username = goa_provider_dialog_add_entry (dialog, group, _("User_name"));
   data->password = goa_provider_dialog_add_password_entry (dialog, group, _("_Password"));
