@@ -118,21 +118,6 @@ imap_auth_login_check_not_CAPABILITY (const gchar *response)
   return FALSE;
 }
 
-static gboolean
-imap_auth_login_check_not_LOGIN (const gchar *response, GError **error)
-{
-  if (strstr (response, "AUTH=PLAIN") == NULL)
-    {
-      g_set_error (error,
-                   GOA_ERROR,
-                   GOA_ERROR_NOT_SUPPORTED,
-                   _("Server does not support PLAIN"));
-      return TRUE;
-    }
-
-  return FALSE;
-}
-
 static gboolean
 imap_auth_login_check_not_OK (const gchar *response, gboolean tagged, GError **error)
 {
@@ -395,32 +380,6 @@ goa_imap_auth_login_run_sync (GoaMailAuth         *auth,
       g_clear_pointer (&response, g_free);
     }
 
-  /* Send CAPABILITY */
-
-  request = g_strdup_printf ("%s CAPABILITY\r\n", IMAP_TAG);
-  g_debug ("> %s", request);
-  if (!g_data_output_stream_put_string (output, request, cancellable, error))
-    goto out;
-  g_clear_pointer (&request, g_free);
-
-  /* Check if LOGIN is supported or not */
-
-  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
-  if (response == NULL)
-    goto out;
-  g_debug ("< %s", response);
-  if (imap_auth_login_check_not_LOGIN (response, error))
-    goto out;
-  g_clear_pointer (&response, g_free);
-
-  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
-  if (response == NULL)
-    goto out;
-  g_debug ("< %s", response);
-  if (imap_auth_login_check_not_OK (response, TRUE, error))
-    goto out;
-  g_clear_pointer (&response, g_free);
-
   /* Send LOGIN */
 
   request = g_strdup_printf ("%s LOGIN \"%s\" \"%s\"\r\n", IMAP_TAG, self->username, password);
