@@ -26,8 +26,6 @@
 #include <gio/gio.h>
 #include <goabackend/goaoauth2provider.h>
 #include <goabackend/goaprovider-priv.h>
-#include <webkit2/webkit2.h>
-#include <webkitdom/webkitdom.h>
 
 G_BEGIN_DECLS
 
@@ -47,16 +45,11 @@ G_BEGIN_DECLS
  * @get_scope: Virtual function for goa_oauth2_provider_get_scope().
  * @get_client_id: Virtual function for goa_oauth2_provider_get_client_id().
  * @get_client_secret: Virtual function for goa_oauth2_provider_get_client_secret().
- * @get_authentication_cookie: Virtual function for goa_oauth2_provider_get_authentication_cookie().
  * @get_identity_sync: Virtual function for goa_oauth2_provider_get_identity_sync().
  * @build_authorization_uri: Virtual function for goa_oauth2_provider_build_authorization_uri().
  * @get_use_mobile_browser: Virtual function for goa_oauth2_provider_get_use_mobile_browser().
  * @add_account_key_values: Virtual function for goa_oauth2_provider_add_account_key_values().
- * @decide_navigation_policy: Virtual function for goa_oauth2_provider_decide_navigation_policy().
  * @process_redirect_url: Virtual function for goa_oauth2_provider_process_redirect_url().
- * @is_deny_node: Virtual function for goa_oauth2_provider_is_deny_node().
- * @is_identity_node: Virtual function for goa_oauth2_provider_is_identity_node().
- * @is_password_node: Virtual function for goa_oauth2_provider_is_password_node().
  *
  * Class structure for #GoaOAuth2Provider.
  */
@@ -69,7 +62,6 @@ struct _GoaOAuth2ProviderClass
   const gchar *(*get_redirect_uri)             (GoaOAuth2Provider            *provider);
   const gchar *(*get_client_id)                (GoaOAuth2Provider            *provider);
   const gchar *(*get_client_secret)            (GoaOAuth2Provider            *provider);
-  const gchar *(*get_authentication_cookie)    (GoaOAuth2Provider            *provider);
   gchar       *(*get_identity_sync)            (GoaOAuth2Provider            *provider,
                                                 const gchar                  *access_token,
                                                 gchar                       **out_presentation_identity,
@@ -88,27 +80,11 @@ struct _GoaOAuth2ProviderClass
   void         (*add_account_key_values)       (GoaOAuth2Provider            *provider,
                                                 GVariantBuilder              *builder);
 
-  /* pure virtual */
-  gboolean     (*is_identity_node)             (GoaOAuth2Provider            *provider,
-                                                WebKitDOMHTMLInputElement    *element);
-
   /* virtual but with default implementation */
-  gboolean     (*is_deny_node)                 (GoaOAuth2Provider            *provider,
-                                                WebKitDOMNode                *node);
-  gboolean     (*is_password_node)             (GoaOAuth2Provider            *provider,
-                                                WebKitDOMHTMLInputElement    *element);
-  gboolean     (*decide_navigation_policy)     (GoaOAuth2Provider              *provider,
-                                                WebKitWebView                  *web_view,
-                                                WebKitNavigationPolicyDecision *decision);
   gboolean     (*process_redirect_url)         (GoaOAuth2Provider            *provider,
                                                 const gchar                  *redirect_url,
                                                 gchar                       **access_token,
                                                 GError                      **error);
-
-
-  /*< private >*/
-  /* Padding for future expansion */
-  gpointer goa_reserved[28];
 };
 
 G_END_DECLS
