@@ -32,169 +32,6 @@ static const SecretSchema secret_password_schema =
   }
 };
 
-typedef struct
-{
-  GoaClient *client;
-  GoaObject *object;
-  GoaProvider *provider;
-} AttentionNeededData;
-
-static AttentionNeededData *
-attention_needed_data_new (GoaClient *client, GoaObject *object, GoaProvider *provider)
-{
-  AttentionNeededData *data;
-
-  data = g_slice_new0 (AttentionNeededData);
-  data->client = g_object_ref (client);
-  data->object = g_object_ref (object);
-  data->provider = g_object_ref (provider);
-
-  return data;
-}
-
-static void
-attention_needed_data_free (AttentionNeededData *data)
-{
-  g_object_unref (data->client);
-  g_object_unref (data->object);
-  g_object_unref (data->provider);
-  g_slice_free (AttentionNeededData, data);
-}
-
-static void
-goa_utils_account_add_attention_needed_info_bar_response (GtkInfoBar *info_bar,
-                                                          gint        response_id,
-                                                          gpointer    user_data)
-{
-  AttentionNeededData *data = (AttentionNeededData *) user_data;
-  GtkWidget *parent;
-  GError *error;
-
-  g_return_if_fail (response_id == GTK_RESPONSE_OK);
-
-  parent = gtk_widget_get_toplevel (GTK_WIDGET (info_bar));
-  if (!gtk_widget_is_toplevel (parent))
-    {
-      g_warning ("Unable to find a toplevel GtkWindow");
-      return;
-    }
-
-  error = NULL;
-  if (!goa_provider_refresh_account (data->provider, data->client, data->object, GTK_WINDOW (parent), &error))
-    {
-      if (!(error->domain == GOA_ERROR && error->code == GOA_ERROR_DIALOG_DISMISSED))
-        {
-          GtkWidget *dialog;
-          dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
-                                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                           GTK_MESSAGE_ERROR,
-                                           GTK_BUTTONS_CLOSE,
-                                           _("Error logging into the account"));
-          gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                                    "%s",
-                                                    error->message);
-          gtk_widget_show_all (dialog);
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
-        }
-      g_error_free (error);
-    }
-}
-
-void
-goa_utils_account_add_attention_needed (GoaClient *client, GoaObject *object, GoaProvider *provider, GtkBox *vbox)
-{
-  AttentionNeededData *data;
-  GoaAccount *account;
-  GtkWidget *button;
-  GtkWidget *content_area;
-  GtkWidget *info_bar;
-  GtkWidget *label;
-  GtkWidget *labels_grid;
-  gchar *markup = NULL;
-
-  account = goa_object_peek_account (object);
-  if (!goa_account_get_attention_needed (account))
-    goto out;
-
-  info_bar = gtk_info_bar_new ();
-  gtk_container_add (GTK_CONTAINER (vbox), info_bar);
-
-  content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
-  gtk_widget_set_margin_start (content_area, 6);
-
-  labels_grid = gtk_grid_new ();
-  gtk_widget_set_halign (labels_grid, GTK_ALIGN_FILL);
-  gtk_widget_set_hexpand (labels_grid, TRUE);
-  gtk_widget_set_valign (labels_grid, GTK_ALIGN_CENTER);
-  gtk_orientable_set_orientation (GTK_ORIENTABLE (labels_grid), GTK_ORIENTATION_VERTICAL);
-  gtk_grid_set_column_spacing (GTK_GRID (labels_grid), 0);
-  gtk_container_add (GTK_CONTAINER (content_area), labels_grid);
-
-  label = gtk_label_new ("");
-  gtk_widget_set_halign (label, GTK_ALIGN_START);
-  markup = g_strdup_printf ("<b>%s</b>", _("Credentials have expired"));
-  gtk_label_set_markup (GTK_LABEL (label), markup);
-  gtk_container_add (GTK_CONTAINER (labels_grid), label);
-
-  label = gtk_label_new (_("Sign in to enable this account."));
-  gtk_widget_set_halign (label, GTK_ALIGN_START);
-  gtk_container_add (GTK_CONTAINER (labels_grid), label);
-
-  button = gtk_info_bar_add_button (GTK_INFO_BAR (info_bar), _("_Sign In"), GTK_RESPONSE_OK);
-  gtk_widget_set_margin_end (button, 6);
-
-  data = attention_needed_data_new (client, object, provider);
-  g_signal_connect_data (info_bar,
-                         "response",
-                         G_CALLBACK (goa_utils_account_add_attention_needed_info_bar_response),
-                         data,
-                         (GClosureNotify) attention_needed_data_free,
-                         0);
-
- out:
-  g_free (markup);
-}
-
-void
-goa_utils_account_add_header (GoaObject *object, GtkGrid *grid, gint row)
-{
-  GIcon *icon;
-  GoaAccount *account;
-  GtkWidget *image;
-  GtkWidget *label;
-  const gchar *icon_str;
-  const gchar *identity;
-  const gchar *name;
-  gchar *markup;
-
-  account = goa_object_peek_account (object);
-
-  icon_str = goa_account_get_provider_icon (account);
-  icon = g_icon_new_for_string (icon_str, NULL);
-  image = gtk_image_new_from_gicon (icon, GTK_ICON_SIZE_DIALOG);
-  g_object_unref (icon);
-  gtk_widget_set_halign (image, GTK_ALIGN_END);
-  gtk_widget_set_hexpand (image, TRUE);
-  gtk_widget_set_margin_bottom (image, 12);
-  gtk_grid_attach (grid, image, 0, row, 1, 1);
-
-  name = goa_account_get_provider_name (account);
-  identity = goa_account_get_presentation_identity (account);
-  markup = g_strdup_printf ("<b>%s</b>\n%s",
-                            name,
-                            (identity == NULL || identity[0] == '\0') ? "\xe2\x80\x94" : identity);
-  label = gtk_label_new (NULL);
-  gtk_label_set_markup (GTK_LABEL (label), markup);
-  gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
-  gtk_label_set_max_width_chars (GTK_LABEL (label), 24);
-  gtk_label_set_width_chars (GTK_LABEL (label), 24);
-  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-  gtk_widget_set_margin_bottom (label, 12);
-  g_free (markup);
-  gtk_grid_attach (grid, label, 1, row, 3, 1);
-}
-
 gboolean
 goa_utils_check_duplicate (GoaClient              *client,
                            const gchar            *identity,
@@ -302,23 +139,6 @@ goa_utils_data_input_stream_read_line (GDataInputStream  *stream,
   return ret;
 }
 
-void
-goa_utils_set_dialog_title (GoaProvider *provider, GtkDialog *dialog, gboolean add_account)
-{
-  gchar *provider_name;
-  gchar *title;
-
-  provider_name = goa_provider_get_provider_name (GOA_PROVIDER (provider), NULL);
-  /* Translators: this is the title of the "Add Account" and "Refresh
-   * Account" dialogs. The %s is the name of the provider. eg.,
-   * 'Google'.
-   */
-  title = g_strdup_printf (_("%s Account"), provider_name);
-  gtk_window_set_title (GTK_WINDOW (dialog), title);
-  g_free (title);
-  g_free (provider_name);
-}
-
 gboolean
 goa_utils_delete_credentials_for_account_sync (GoaProvider   *provider,
                                                GoaAccount    *object,
@@ -363,7 +183,7 @@ goa_utils_delete_credentials_for_id_sync (GoaProvider   *provider,
                               NULL);
   if (sec_error != NULL)
     {
-      g_warning ("secret_password_clear_sync() failed: %s", sec_error->message);
+      g_debug ("secret_password_clear_sync() failed: %s", sec_error->message);
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
@@ -411,7 +231,7 @@ goa_utils_lookup_credentials_sync (GoaProvider   *provider,
                                           NULL);
   if (sec_error != NULL)
     {
-      g_warning ("secret_password_lookup_sync() failed: %s", sec_error->message);
+      g_debug ("secret_password_lookup_sync() failed: %s", sec_error->message);
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
@@ -421,7 +241,7 @@ goa_utils_lookup_credentials_sync (GoaProvider   *provider,
     }
   else if (password == NULL)
     {
-      g_warning ("secret_password_lookup_sync() returned NULL");
+      g_debug ("secret_password_lookup_sync() returned NULL");
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
@@ -492,7 +312,7 @@ goa_utils_store_credentials_for_id_sync (GoaProvider   *provider,
                                    "goa-identity", password_key,
                                    NULL))
     {
-      g_warning ("secret_password_store_sync() failed: %s", sec_error->message);
+      g_debug ("secret_password_store_sync() failed: %s", sec_error->message);
       g_set_error_literal (error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
@@ -545,11 +365,11 @@ goa_utils_keyfile_copy_group (GKeyFile     *src_key_file,
   keys = g_key_file_get_keys (src_key_file, src_group_name, NULL, &error);
   if (error != NULL)
     {
-      g_warning ("Error getting keys from group %s: %s (%s, %d)",
-                 src_group_name,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      g_debug ("Error getting keys from group %s: %s (%s, %d)",
+               src_group_name,
+               error->message,
+               g_quark_to_string (error->domain),
+               error->code);
       g_error_free (error);
       goto out;
     }
@@ -563,12 +383,12 @@ goa_utils_keyfile_copy_group (GKeyFile     *src_key_file,
       src_value = g_key_file_get_value (src_key_file, src_group_name, keys[i], &error);
       if (error != NULL)
         {
-          g_warning ("Error reading key %s from group %s: %s (%s, %d)",
-                     keys[i],
-                     src_group_name,
-                     error->message,
-                     g_quark_to_string (error->domain),
-                     error->code);
+          g_debug ("Error reading key %s from group %s: %s (%s, %d)",
+                   keys[i],
+                   src_group_name,
+                   error->message,
+                   g_quark_to_string (error->domain),
+                   error->code);
           g_error_free (error);
           continue;
         }
@@ -580,12 +400,12 @@ goa_utils_keyfile_copy_group (GKeyFile     *src_key_file,
           if (!g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND)
               && !g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_KEY_NOT_FOUND))
             {
-              g_warning ("Error reading key %s from group %s: %s (%s, %d)",
-                         keys[i],
-                         src_group_name,
-                         error->message,
-                         g_quark_to_string (error->domain),
-                         error->code);
+              g_debug ("Error reading key %s from group %s: %s (%s, %d)",
+                       keys[i],
+                       src_group_name,
+                       error->message,
+                       g_quark_to_string (error->domain),
+                       error->code);
             }
 
           g_error_free (error);
@@ -618,12 +438,12 @@ goa_utils_keyfile_get_boolean (GKeyFile *key_file, const gchar *group_name, cons
     {
       if (!g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_KEY_NOT_FOUND))
         {
-          g_warning ("Error reading key %s from group %s in keyfile: %s (%s, %d)",
-                     key,
-                     group_name,
-                     error->message,
-                     g_quark_to_string (error->domain),
-                     error->code);
+          g_debug ("Error reading key %s from group %s in keyfile: %s (%s, %d)",
+                   key,
+                   group_name,
+                   error->message,
+                   g_quark_to_string (error->domain),
+                   error->code);
         }
 
       g_error_free (error);
@@ -650,11 +470,11 @@ goa_utils_keyfile_remove_key (GoaAccount *account, const gchar *key)
                                   G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS,
                                   &error))
     {
-      g_warning ("Error loading keyfile %s: %s (%s, %d)",
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      g_debug ("Error loading keyfile %s: %s (%s, %d)",
+               path,
+               error->message,
+               g_quark_to_string (error->domain),
+               error->code);
       g_error_free (error);
       goto out;
     }
@@ -666,7 +486,7 @@ goa_utils_keyfile_remove_key (GoaAccount *account, const gchar *key)
   if (!g_key_file_save_to_file (key_file, path, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
-      g_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
+      g_debug ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
       g_error_free (error);
       goto out;
     }
@@ -697,11 +517,11 @@ goa_utils_keyfile_set_boolean (GoaAccount *account, const gchar *key, gboolean v
                                   G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS,
                                   &error))
     {
-      g_warning ("Error loading keyfile %s: %s (%s, %d)",
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      g_debug ("Error loading keyfile %s: %s (%s, %d)",
+               path,
+               error->message,
+               g_quark_to_string (error->domain),
+               error->code);
       g_error_free (error);
       goto out;
     }
@@ -710,12 +530,12 @@ goa_utils_keyfile_set_boolean (GoaAccount *account, const gchar *key, gboolean v
   old_value = g_key_file_get_boolean (key_file, group, key, &error);
   if (error != NULL)
     {
-      g_warning ("Error reading key %s from keyfile %s: %s (%s, %d)",
-                 key,
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      g_debug ("Error reading key %s from keyfile %s: %s (%s, %d)",
+               key,
+               path,
+               error->message,
+               g_quark_to_string (error->domain),
+               error->code);
       needs_update = TRUE;
       g_error_free (error);
     }
@@ -733,7 +553,7 @@ goa_utils_keyfile_set_boolean (GoaAccount *account, const gchar *key, gboolean v
   if (!g_key_file_save_to_file (key_file, path, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
-      g_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
+      g_debug ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
       g_error_free (error);
       goto out;
     }
@@ -764,11 +584,11 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
                                   G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS,
                                   &error))
     {
-      g_warning ("Error loading keyfile %s: %s (%s, %d)",
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      g_debug ("Error loading keyfile %s: %s (%s, %d)",
+               path,
+               error->message,
+               g_quark_to_string (error->domain),
+               error->code);
       g_error_free (error);
       goto out;
     }
@@ -777,12 +597,12 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
   old_value = g_key_file_get_string (key_file, group, key, &error);
   if (error != NULL)
     {
-      g_warning ("Error reading key %s from keyfile %s: %s (%s, %d)",
-                 key,
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
+      g_debug ("Error reading key %s from keyfile %s: %s (%s, %d)",
+               key,
+               path,
+               error->message,
+               g_quark_to_string (error->domain),
+               error->code);
       needs_update = TRUE;
       g_error_free (error);
     }
@@ -800,7 +620,7 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
   if (!g_key_file_save_to_file (key_file, path, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
-      g_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
+      g_debug ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
       g_error_free (error);
       goto out;
     }
@@ -846,9 +666,13 @@ goa_utils_set_error_soup (GError **err, SoupMessage *msg)
   status_code = soup_message_get_status (msg);
   switch (status_code)
     {
+    case SOUP_STATUS_METHOD_NOT_ALLOWED:
     case SOUP_STATUS_INTERNAL_SERVER_ERROR:
+    case SOUP_STATUS_NOT_IMPLEMENTED:
+      error_msg = g_strdup (_("Not supported"));
+
     case SOUP_STATUS_NOT_FOUND:
-      error_msg = g_strdup (_("Cannot find WebDAV endpoint"));
+      error_msg = g_strdup (_("Not found"));
       break;
 
     default:
