@@ -39,13 +39,6 @@ G_BEGIN_DECLS
 
 typedef gpointer (*GoaPeekInterfaceFunc)   (GoaObject *);
 
-void             goa_utils_account_add_attention_needed (GoaClient    *client,
-                                                         GoaObject    *object,
-                                                         GoaProvider  *provider,
-                                                         GtkBox       *vbox);
-
-void             goa_utils_account_add_header (GoaObject *object, GtkGrid *grid, gint row);
-
 gboolean         goa_utils_check_duplicate (GoaClient              *client,
                                             const gchar            *identity,
                                             const gchar            *presentation_identity,
@@ -62,8 +55,6 @@ gchar           *goa_utils_data_input_stream_read_line (GDataInputStream  *strea
                                                         GCancellable      *cancellable,
                                                         GError           **error);
 
-void             goa_utils_set_dialog_title (GoaProvider *provider, GtkDialog *dialog, gboolean add_account);
-
 gboolean         goa_utils_delete_credentials_for_account_sync (GoaProvider    *provider,
                                                                 GoaAccount     *account,
                                                                 GCancellable   *cancellable,
