@@ -47,7 +47,6 @@ struct _GoaKerberosIdentityManager
 
   krb5_context kerberos_context;
   GFileMonitor *credentials_cache_monitor;
-  gulong credentials_cache_changed_signal_id;
   char *credentials_cache_type;
 
   GMutex scheduler_job_lock;
@@ -282,12 +281,29 @@ identity_signal_work_free (IdentitySignalWork *work)
   g_slice_free (IdentitySignalWork, work);
 }
 
+static void
+do_identity_signal_expired_work (IdentitySignalWork *work)
+{
+  GoaKerberosIdentityManager *self = work->manager;
+  GoaIdentity *identity = work->identity;
+
+  g_debug ("GoaKerberosIdentityManager: identity expired");
+  _goa_identity_manager_emit_identity_expired (GOA_IDENTITY_MANAGER (self), identity);
+}
+
 static void
 on_identity_expired (GoaIdentity                *identity,
                      GoaKerberosIdentityManager *self)
 {
-  _goa_identity_manager_emit_identity_expired (GOA_IDENTITY_MANAGER (self),
-                                               identity);
+  IdentitySignalWork *work;
+
+  work = identity_signal_work_new (self, identity);
+  goa_kerberos_identify_manager_send_to_context (g_main_context_default (),
+                                                 (GSourceFunc)
+                                                 do_identity_signal_expired_work,
+                                                 work,
+                                                 (GDestroyNotify)
+                                                 identity_signal_work_free);
 }
 
 static void
@@ -499,34 +515,6 @@ drop_stale_identities (GoaKerberosIdentityManager *self,
   g_list_free (stale_identity_ids);
 }
 
-static void
-update_identity (GoaKerberosIdentityManager *self,
-                 Operation                  *operation,
-                 GoaIdentity                *identity,
-                 GoaIdentity                *new_identity)
-{
-
-  goa_kerberos_identity_update (GOA_KERBEROS_IDENTITY (identity),
-                                GOA_KERBEROS_IDENTITY (new_identity));
-
-  if (goa_identity_is_signed_in (identity))
-    {
-      IdentitySignalWork *work;
-
-      /* if it's not expired, send out a refresh signal */
-      g_debug ("GoaKerberosIdentityManager: identity '%s' refreshed",
-               goa_identity_get_identifier (identity));
-
-      work = identity_signal_work_new (self, identity);
-      goa_kerberos_identify_manager_send_to_context (operation->context,
-                                                     (GSourceFunc)
-                                                     do_identity_signal_refreshed_work,
-                                                     work,
-                                                     (GDestroyNotify)
-                                                     identity_signal_work_free);
-    }
-}
-
 static void
 add_identity (GoaKerberosIdentityManager *self,
               Operation                  *operation,
@@ -548,40 +536,69 @@ add_identity (GoaKerberosIdentityManager *self,
                                                  (GDestroyNotify) identity_signal_work_free);
 }
 
-static void
-refresh_identity (GoaKerberosIdentityManager *self,
-                  Operation                  *operation,
-                  GHashTable                 *refreshed_identities,
-                  GoaIdentity                *identity)
+static char *
+get_principal_from_cache (GoaKerberosIdentityManager *self,
+                          krb5_ccache                 cache)
 {
-  const char *identifier;
-  GoaIdentity *old_identity;
+  int error_code;
+  krb5_principal principal;
+  char *unparsed_name;
+  char *principal_name;
 
-  identifier = goa_identity_get_identifier (identity);
+  error_code = krb5_cc_get_principal (self->kerberos_context, cache, &principal);
+
+  error_code = krb5_unparse_name_flags (self->kerberos_context, principal, 0, &unparsed_name);
+  krb5_free_principal (self->kerberos_context, principal);
+
+  if (error_code != 0)
+    return NULL;
+
+  principal_name = g_strdup (unparsed_name);
+
+  krb5_free_unparsed_name (self->kerberos_context, unparsed_name);
+
+  return principal_name;
+}
+
+static void
+import_credentials_cache (GoaKerberosIdentityManager *self,
+                          Operation                  *operation,
+                          GHashTable                 *refreshed_identities,
+                          krb5_ccache                 cache)
+{
+  g_autofree char *identifier = NULL;
+  GoaIdentity *identity = NULL;
+
+  identifier = get_principal_from_cache (self, cache);
 
   if (identifier == NULL)
     return;
 
-  old_identity = g_hash_table_lookup (self->identities, identifier);
+  identity = g_hash_table_lookup (self->identities, identifier);
 
-  if (old_identity != NULL)
+  if (identity == NULL)
     {
-      g_debug ("GoaKerberosIdentityManager: refreshing identity '%s'", identifier);
-      update_identity (self, operation, old_identity, identity);
+      g_autoptr(GError) error = NULL;
 
-      /* Reuse the old identity, so any object data set up on it doesn't
-       * disappear spurriously
-       */
-      identifier = goa_identity_get_identifier (old_identity);
-      identity = old_identity;
+      g_debug ("GoaKerberosIdentityManager: Adding new identity '%s'", identifier);
+      identity = goa_kerberos_identity_new (self->kerberos_context, cache, &error);
+
+      if (error != NULL)
+        {
+          g_debug ("GoaKerberosIdentityManager: Could not track identity %s: %s",
+                   identifier, error->message);
+          return;
+        }
+
+      add_identity (self, operation, identity, identifier);
     }
   else
     {
-      g_debug ("GoaKerberosIdentityManager: adding new identity '%s'", identifier);
-      add_identity (self, operation, identity, identifier);
+      if (!goa_kerberos_identity_has_credentials_cache (GOA_KERBEROS_IDENTITY (identity), cache))
+        goa_kerberos_identity_add_credentials_cache (GOA_KERBEROS_IDENTITY (identity), cache);
     }
 
-  /* Track refreshed identities so we can emit removals when we're done fully
+  /* Track refreshed identities so we can emit refreshes and removals when we're done fully
    * enumerating the collection of credential caches
    */
   g_hash_table_replace (refreshed_identities,
@@ -598,6 +615,9 @@ refresh_identities (GoaKerberosIdentityManager *self,
   krb5_cccol_cursor cursor;
   const char *error_message;
   GHashTable *refreshed_identities;
+  GHashTableIter iter;
+  const char *name;
+  GoaIdentity *identity;
 
   /* If we have more refreshes queued up, don't bother doing this one
    */
@@ -623,15 +643,7 @@ refresh_identities (GoaKerberosIdentityManager *self,
 
   while (error_code == 0 && cache != NULL)
     {
-      GoaIdentity *identity;
-
-      identity = goa_kerberos_identity_new (self->kerberos_context, cache, NULL);
-
-      if (identity != NULL)
-        {
-          refresh_identity (self, operation, refreshed_identities, identity);
-          g_object_unref (identity);
-        }
+      import_credentials_cache (self, operation, refreshed_identities, cache);
 
       krb5_cc_close (self->kerberos_context, cache);
       error_code = krb5_cccol_cursor_next (self->kerberos_context, cursor, &cache);
@@ -646,6 +658,30 @@ refresh_identities (GoaKerberosIdentityManager *self,
     }
 
   krb5_cccol_cursor_free (self->kerberos_context, &cursor);
+
+  g_hash_table_iter_init (&iter, self->identities);
+  while (g_hash_table_iter_next (&iter, (gpointer *) &name, (gpointer*) &identity))
+    {
+      goa_kerberos_identity_refresh (GOA_KERBEROS_IDENTITY (identity));
+
+      if (goa_identity_is_signed_in (identity))
+        {
+          IdentitySignalWork *work;
+
+          /* if it's not expired, send out a refresh signal */
+          g_debug ("GoaKerberosIdentityManager: identity '%s' refreshed",
+                   goa_identity_get_identifier (identity));
+
+          work = identity_signal_work_new (self, identity);
+          goa_kerberos_identify_manager_send_to_context (operation->context,
+                                                         (GSourceFunc)
+                                                         do_identity_signal_refreshed_work,
+                                                         work,
+                                                         (GDestroyNotify)
+                                                         identity_signal_work_free);
+        }
+    }
+
 done:
   drop_stale_identities (self, operation, refreshed_identities);
   g_hash_table_unref (refreshed_identities);
@@ -707,6 +743,7 @@ renew_identity (GoaKerberosIdentityManager *self,
                error->message);
 
       g_task_return_error (operation->task, error);
+      return;
     }
 
   g_task_return_boolean (operation->task, was_renewed);
@@ -834,7 +871,9 @@ get_new_credentials_cache (GoaKerberosIdentityManager *self,
                self->credentials_cache_type);
       supports_multiple_identities = FALSE;
     }
-  else if (g_strcmp0 (self->credentials_cache_type, "DIR") == 0 || g_strcmp0 (self->credentials_cache_type, "KEYRING") == 0)
+  else if (g_strcmp0 (self->credentials_cache_type, "DIR") == 0
+           || g_strcmp0 (self->credentials_cache_type, "KCM") == 0
+           || g_strcmp0 (self->credentials_cache_type, "KEYRING") == 0)
     {
       g_debug ("GoaKerberosIdentityManager: credential cache type %s supports cache collections", self->credentials_cache_type);
       supports_multiple_identities = TRUE;
@@ -1432,8 +1471,7 @@ monitor_credentials_cache (GoaKerberosIdentityManager  *self,
     }
   else
     {
-      self->credentials_cache_changed_signal_id = g_signal_connect (G_OBJECT (monitor), "changed",
-                                                                    G_CALLBACK (on_credentials_cache_changed), self);
+      g_signal_connect (G_OBJECT (monitor), "changed", G_CALLBACK (on_credentials_cache_changed), self);
       self->credentials_cache_monitor = monitor;
     }
 
